Re: speed of require/include
| From: | Tac Tacelosky | Date: | Wed, 20 Oct 2010 21:05:24 +0000 |
| Subject: | Re: speed of require/include | ||
| References: | 1 | Groups: | php.windows |
| Request: | Send a blank email to php-windows+get-30366@lists.php.net to get a copy of this message | ||
If you have the RAM, install php_apc -- once the scripts are included once,
the tokenized php will be cached in memory, can be a significant performance
boost.
We also use it for "global" variables that don't change across scripts, such
as state and country names. Great tool, I wish it were built into PHP
instead of a pecl module.
Tac
On Wed, Oct 20, 2010 at 4:50 PM, Tommy Pham <tommyhp2@gmail.com> wrote:
> Hi everyone,
>
> I think this question is general PHP but because I'm using Windows for
> development at the moment and was wondering if it's related to Windows.
> Does the speed of require/require_once/include/include_once depends on disk
> activity, buffers (disks, controller, Windows)? I can't seem to get steady
> time from xdebug profile... it varies from 27ms to 170ms on one of my
> scripts while another script in the same framework with less
> require/include
> always have a steady ~6.5ms (the previous has 30 requires/includes and the
> latter has 8 requires/includes). I only have the skeleton of the framework
> for my project (no DB access, no fancy html/xml output). I'm running PHP
> 5.3.3 FastCGI on Windows 2008 R2 x64 w/ 4GB RAM. SATA RAID controller is
> 3ware 9650se.
>
> Thanks for your time,
> Tommy
>
>
> --
> PHP Windows Mailing List (http://www.php.net/)
> To unsubscribe, visit: http://www.php.net/unsub.php
>
>
--
Please note my new phone number: (202) 656-7822